@@ -12,10 +12,33 @@ Usage::
 import sys
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_ce.literals import (
+    AccountScope,
+    AnomalyFeedbackType,
+    AnomalySubscriptionFrequency,
+    CostCategoryInheritedValueDimensionName,
+    CostCategoryRuleType,
+    CostCategoryRuleVersion,
+    CostCategoryStatus,
+    CostCategoryStatusComponent,
+    Dimension,
+    GroupDefinitionType,
+    LookbackPeriodInDays,
+    MatchOption,
+    MonitorDimension,
+    MonitorType,
+    NumericOperator,
+    OfferingClass,
+    PaymentOption,
+    RecommendationTarget,
+    RightsizingType,
+    SortOrder,
+    SubscriberStatus,
+    SubscriberType,
+    SupportedSavingsPlansType,
+    TermInYears,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -127,8 +150,7 @@ __all__ = (
 )
 
 _RequiredAnomalyMonitorTypeDef = TypedDict(
-    "_RequiredAnomalyMonitorTypeDef",
-    {"MonitorName": str, "MonitorType": Literal["DIMENSIONAL", "CUSTOM"]},
+    "_RequiredAnomalyMonitorTypeDef", {"MonitorName": str, "MonitorType": MonitorType}
 )
 _OptionalAnomalyMonitorTypeDef = TypedDict(
     "_OptionalAnomalyMonitorTypeDef",
@@ -137,7 +159,7 @@ _OptionalAnomalyMonitorTypeDef = TypedDict(
         "CreationDate": str,
         "LastUpdatedDate": str,
         "LastEvaluatedDate": str,
-        "MonitorDimension": Literal["SERVICE"],
+        "MonitorDimension": MonitorDimension,
         "MonitorSpecification": Dict[str, Any],
         "DimensionalValueCount": int,
     },
@@ -157,7 +179,7 @@ _RequiredAnomalySubscriptionTypeDef = TypedDict(
         "MonitorArnList": List[str],
         "Subscribers": List["SubscriberTypeDef"],
         "Threshold": float,
-        "Frequency": Literal["DAILY", "IMMEDIATE", "WEEKLY"],
+        "Frequency": AnomalySubscriptionFrequency,
         "SubscriptionName": str,
     },
 )
@@ -188,7 +210,7 @@ _OptionalAnomalyTypeDef = TypedDict(
         "AnomalyEndDate": str,
         "DimensionValue": str,
         "RootCauses": List["RootCauseTypeDef"],
-        "Feedback": Literal["YES", "NO", "PLANNED_ACTIVITY"],
+        "Feedback": AnomalyFeedbackType,
     },
     total=False,
 )
@@ -200,13 +222,13 @@ class AnomalyTypeDef(_RequiredAnomalyTypeDef, _OptionalAnomalyTypeDef):
 
 CostCategoryInheritedValueDimensionTypeDef = TypedDict(
     "CostCategoryInheritedValueDimensionTypeDef",
-    {"DimensionName": Literal["LINKED_ACCOUNT_NAME", "TAG"], "DimensionKey": str},
+    {"DimensionName": CostCategoryInheritedValueDimensionName, "DimensionKey": str},
     total=False,
 )
 
 CostCategoryProcessingStatusTypeDef = TypedDict(
     "CostCategoryProcessingStatusTypeDef",
-    {"Component": Literal["COST_EXPLORER"], "Status": Literal["PROCESSING", "APPLIED"]},
+    {"Component": CostCategoryStatusComponent, "Status": CostCategoryStatus},
     total=False,
 )
 
@@ -231,7 +253,7 @@ CostCategoryRuleTypeDef = TypedDict(
         "Value": str,
         "Rule": Dict[str, Any],
         "InheritedValue": "CostCategoryInheritedValueDimensionTypeDef",
-        "Type": Literal["REGULAR", "INHERITED_VALUE"],
+        "Type": CostCategoryRuleType,
     },
     total=False,
 )
@@ -242,7 +264,7 @@ _RequiredCostCategoryTypeDef = TypedDict(
         "CostCategoryArn": str,
         "EffectiveStart": str,
         "Name": str,
-        "RuleVersion": Literal["CostCategoryExpression.v1"],
+        "RuleVersion": CostCategoryRuleVersion,
         "Rules": List["CostCategoryRuleTypeDef"],
     },
 )
@@ -263,21 +285,7 @@ class CostCategoryTypeDef(_RequiredCostCategoryTypeDef, _OptionalCostCategoryTyp
 
 CostCategoryValuesTypeDef = TypedDict(
     "CostCategoryValuesTypeDef",
-    {
-        "Key": str,
-        "Values": List[str],
-        "MatchOptions": List[
-            Literal[
-                "EQUALS",
-                "ABSENT",
-                "STARTS_WITH",
-                "ENDS_WITH",
-                "CONTAINS",
-                "CASE_SENSITIVE",
-                "CASE_INSENSITIVE",
-            ]
-        ],
-    },
+    {"Key": str, "Values": List[str], "MatchOptions": List[MatchOption]},
     total=False,
 )
 
@@ -347,53 +355,7 @@ DateIntervalTypeDef = TypedDict("DateIntervalTypeDef", {"Start": str, "End": str
 
 DimensionValuesTypeDef = TypedDict(
     "DimensionValuesTypeDef",
-    {
-        "Key": Literal[
-            "AZ",
-            "INSTANCE_TYPE",
-            "LINKED_ACCOUNT",
-            "LINKED_ACCOUNT_NAME",
-            "OPERATION",
-            "PURCHASE_TYPE",
-            "REGION",
-            "SERVICE",
-            "SERVICE_CODE",
-            "USAGE_TYPE",
-            "USAGE_TYPE_GROUP",
-            "RECORD_TYPE",
-            "OPERATING_SYSTEM",
-            "TENANCY",
-            "SCOPE",
-            "PLATFORM",
-            "SUBSCRIPTION_ID",
-            "LEGAL_ENTITY_NAME",
-            "DEPLOYMENT_OPTION",
-            "DATABASE_ENGINE",
-            "CACHE_ENGINE",
-            "INSTANCE_TYPE_FAMILY",
-            "BILLING_ENTITY",
-            "RESERVATION_ID",
-            "RESOURCE_ID",
-            "RIGHTSIZING_TYPE",
-            "SAVINGS_PLANS_TYPE",
-            "SAVINGS_PLAN_ARN",
-            "PAYMENT_OPTION",
-            "AGREEMENT_END_DATE_TIME_AFTER",
-            "AGREEMENT_END_DATE_TIME_BEFORE",
-        ],
-        "Values": List[str],
-        "MatchOptions": List[
-            Literal[
-                "EQUALS",
-                "ABSENT",
-                "STARTS_WITH",
-                "ENDS_WITH",
-                "CONTAINS",
-                "CASE_SENSITIVE",
-                "CASE_INSENSITIVE",
-            ]
-        ],
-    },
+    {"Key": Dimension, "Values": List[str], "MatchOptions": List[MatchOption]},
     total=False,
 )
 
@@ -457,7 +419,7 @@ EC2ResourceUtilizationTypeDef = TypedDict(
 )
 
 EC2SpecificationTypeDef = TypedDict(
-    "EC2SpecificationTypeDef", {"OfferingClass": Literal["STANDARD", "CONVERTIBLE"]}, total=False
+    "EC2SpecificationTypeDef", {"OfferingClass": OfferingClass}, total=False
 )
 
 ESInstanceDetailsTypeDef = TypedDict(
@@ -497,9 +459,7 @@ ForecastResultTypeDef = TypedDict(
 )
 
 GroupDefinitionTypeDef = TypedDict(
-    "GroupDefinitionTypeDef",
-    {"Type": Literal["DIMENSION", "TAG", "COST_CATEGORY"], "Key": str},
-    total=False,
+    "GroupDefinitionTypeDef", {"Type": GroupDefinitionType, "Key": str}, total=False
 )
 
 GroupTypeDef = TypedDict(
@@ -637,17 +597,10 @@ ReservationPurchaseRecommendationSummaryTypeDef = TypedDict(
 ReservationPurchaseRecommendationTypeDef = TypedDict(
     "ReservationPurchaseRecommendationTypeDef",
     {
-        "AccountScope": Literal["PAYER", "LINKED"],
-        "LookbackPeriodInDays": Literal["SEVEN_DAYS", "THIRTY_DAYS", "SIXTY_DAYS"],
-        "TermInYears": Literal["ONE_YEAR", "THREE_YEARS"],
-        "PaymentOption": Literal[
-            "NO_UPFRONT",
-            "PARTIAL_UPFRONT",
-            "ALL_UPFRONT",
-            "LIGHT_UTILIZATION",
-            "MEDIUM_UTILIZATION",
-            "HEAVY_UTILIZATION",
-        ],
+        "AccountScope": AccountScope,
+        "LookbackPeriodInDays": LookbackPeriodInDays,
+        "TermInYears": TermInYears,
+        "PaymentOption": PaymentOption,
         "ServiceSpecification": "ServiceSpecificationTypeDef",
         "RecommendationDetails": List["ReservationPurchaseRecommendationDetailTypeDef"],
         "RecommendationSummary": "ReservationPurchaseRecommendationSummaryTypeDef",
@@ -689,10 +642,7 @@ ResultByTimeTypeDef = TypedDict(
 
 RightsizingRecommendationConfigurationTypeDef = TypedDict(
     "RightsizingRecommendationConfigurationTypeDef",
-    {
-        "RecommendationTarget": Literal["SAME_INSTANCE_FAMILY", "CROSS_INSTANCE_FAMILY"],
-        "BenefitsConsidered": bool,
-    },
+    {"RecommendationTarget": RecommendationTarget, "BenefitsConsidered": bool},
 )
 
 RightsizingRecommendationMetadataTypeDef = TypedDict(
@@ -700,7 +650,7 @@ RightsizingRecommendationMetadataTypeDef = TypedDict(
     {
         "RecommendationId": str,
         "GenerationTimestamp": str,
-        "LookbackPeriodInDays": Literal["SEVEN_DAYS", "THIRTY_DAYS", "SIXTY_DAYS"],
+        "LookbackPeriodInDays": LookbackPeriodInDays,
         "AdditionalMetadata": str,
     },
     total=False,
@@ -722,7 +672,7 @@ RightsizingRecommendationTypeDef = TypedDict(
     {
         "AccountId": str,
         "CurrentInstance": "CurrentInstanceTypeDef",
-        "RightsizingType": Literal["TERMINATE", "MODIFY"],
+        "RightsizingType": RightsizingType,
         "ModifyRecommendationDetail": "ModifyRecommendationDetailTypeDef",
         "TerminateRecommendationDetail": "TerminateRecommendationDetailTypeDef",
     },
@@ -822,18 +772,11 @@ SavingsPlansPurchaseRecommendationSummaryTypeDef = TypedDict(
 SavingsPlansPurchaseRecommendationTypeDef = TypedDict(
     "SavingsPlansPurchaseRecommendationTypeDef",
     {
-        "AccountScope": Literal["PAYER", "LINKED"],
-        "SavingsPlansType": Literal["COMPUTE_SP", "EC2_INSTANCE_SP", "SAGEMAKER_SP"],
-        "TermInYears": Literal["ONE_YEAR", "THREE_YEARS"],
-        "PaymentOption": Literal[
-            "NO_UPFRONT",
-            "PARTIAL_UPFRONT",
-            "ALL_UPFRONT",
-            "LIGHT_UTILIZATION",
-            "MEDIUM_UTILIZATION",
-            "HEAVY_UTILIZATION",
-        ],
-        "LookbackPeriodInDays": Literal["SEVEN_DAYS", "THIRTY_DAYS", "SIXTY_DAYS"],
+        "AccountScope": AccountScope,
+        "SavingsPlansType": SupportedSavingsPlansType,
+        "TermInYears": TermInYears,
+        "PaymentOption": PaymentOption,
+        "LookbackPeriodInDays": LookbackPeriodInDays,
         "SavingsPlansPurchaseRecommendationDetails": List[
             "SavingsPlansPurchaseRecommendationDetailTypeDef"
         ],
@@ -916,27 +859,13 @@ ServiceSpecificationTypeDef = TypedDict(
 
 SubscriberTypeDef = TypedDict(
     "SubscriberTypeDef",
-    {"Address": str, "Type": Literal["EMAIL", "SNS"], "Status": Literal["CONFIRMED", "DECLINED"]},
+    {"Address": str, "Type": SubscriberType, "Status": SubscriberStatus},
     total=False,
 )
 
 TagValuesTypeDef = TypedDict(
     "TagValuesTypeDef",
-    {
-        "Key": str,
-        "Values": List[str],
-        "MatchOptions": List[
-            Literal[
-                "EQUALS",
-                "ABSENT",
-                "STARTS_WITH",
-                "ENDS_WITH",
-                "CONTAINS",
-                "CASE_SENSITIVE",
-                "CASE_INSENSITIVE",
-            ]
-        ],
-    },
+    {"Key": str, "Values": List[str], "MatchOptions": List[MatchOption]},
     total=False,
 )
 
@@ -1279,7 +1208,7 @@ ProvideAnomalyFeedbackResponseTypeDef = TypedDict(
 
 _RequiredSortDefinitionTypeDef = TypedDict("_RequiredSortDefinitionTypeDef", {"Key": str})
 _OptionalSortDefinitionTypeDef = TypedDict(
-    "_OptionalSortDefinitionTypeDef", {"SortOrder": Literal["ASCENDING", "DESCENDING"]}, total=False
+    "_OptionalSortDefinitionTypeDef", {"SortOrder": SortOrder}, total=False
 )
 
 
@@ -1288,18 +1217,7 @@ class SortDefinitionTypeDef(_RequiredSortDefinitionTypeDef, _OptionalSortDefinit
 
 
 _RequiredTotalImpactFilterTypeDef = TypedDict(
-    "_RequiredTotalImpactFilterTypeDef",
-    {
-        "NumericOperator": Literal[
-            "EQUAL",
-            "GREATER_THAN_OR_EQUAL",
-            "LESS_THAN_OR_EQUAL",
-            "GREATER_THAN",
-            "LESS_THAN",
-            "BETWEEN",
-        ],
-        "StartValue": float,
-    },
+    "_RequiredTotalImpactFilterTypeDef", {"NumericOperator": NumericOperator, "StartValue": float}
 )
 _OptionalTotalImpactFilterTypeDef = TypedDict(
     "_OptionalTotalImpactFilterTypeDef", {"EndValue": float}, total=False
